/*********************************************************************
 * File:   ttyio.c  (part of TTYTALK)
 * Author: Victor Volkman
 * Date:   June, 1988
 ********************************************************************/
#include "tty.h"

extern int c_row, c_col;
extern enum cmdtype mode;
extern FILE *capture_file;
extern FILE *send_file;
extern int term_vals[];
extern char *term_strs[];
extern int capture_mode;

char *cmd_prompt_str = "Press F2 for Command";

void kbd_cmd()       /* Highest level keyboard handler */
{
    int chr; /* from the keyboard */
    int ticks;   /* break duration    */

    chr = kbinput();
    switch(chr) {
        case F1:
            mode = CMD_QUIT;
            break;

        case F2:
            if (mode == CMD_SEND) close(send_file);
            mode = CMD_NONE;
            line_cmd();
            break;

        case A_B:
            ticks = (term_vals[CMD_LBREAK] * 182064L) / 10000000L;
            send_brk(ticks);
            break;

        default:
            send_char(chr);
            break;
    }
}

int kbinput()        /* get keyboard character from BIOS */
{
    union REGS r;

    r.x.ax = KB_GET;
    int86(KB_INT, &r, &r);
    return (int) (r.h.al ? r.h.al : r.x.ax);
}

void disp_cmdline()   /* display the prompt on line 25 */
{
    int i;

    for (i=0; i<WINDOW_COLS; i++)
        vid_write(CHAR_BLANK,WINDOW_ROWS,i,ATTR_CMD);
    vid_write_str(cmd_prompt_str,WINDOW_ROWS,1,ATTR_CMD);
    vid_setrc(c_row,c_col);
}

void term_error(error_level,desc1,desc2)  /* universal error reporting */
int error_level;
char *desc1, *desc2;
{
    char error_str[80];

    if (desc2==NULL) desc2 = "";
    if (error_level==1)
        sprintf(error_str,"warning:  %s %s",desc1,desc2);
    else
        sprintf(error_str,"error:  %s %s",desc1,desc2);

    vid_write_str(error_str,WINDOW_ROWS-1,1,ATTR_TERM);
    vid_scroll(0,0,WINDOW_ROWS-1,WINDOW_COLS-1,1);
}

void vid_setrc(n_row,n_col)   /* BIOS set cursor */
int n_row;
int n_col;
{
    union REGS r;

    r.h.dh = n_row;   /* cursor row    */
    r.h.dl = n_col;   /* cursor column */
    r.h.bh = 0;       /* video page    */
    r.h.ah = 2;       /* set cursor    */
    int86(VIDEO_INT, &r, &r);
}

void vid_write(chr,scr_row,scr_col,attr)   /* BIOS write character */
int chr;
int scr_row;
int scr_col;
int attr;
{
    union REGS r;

    vid_setrc(scr_row,scr_col);
    r.x.cx = 1;      /* char count */
    r.h.bh = 0;      /* video page */
    r.h.bl = attr;   /* attribute  */
    r.h.al = chr;    /* char   */
    r.h.ah = 9;      /* write      */
    int86(VIDEO_INT, &r, &r);
}

void vid_write_str(use_str,start_row,start_col,attr)
char *use_str;
int start_row;
int start_col;
int attr;
{
    char *s_ptr;

    for (s_ptr=use_str; *s_ptr!='\0'; s_ptr++)
        vid_write(*s_ptr,start_row,start_col++,attr);
}

void vid_scroll(row1,col1,row2,col2,num_rows)   /* BIOS scroll up */
int row1, col1, row2, col2;
int num_rows;
{
    union REGS r;

    r.h.ch = row1;   /* upper-left corner  */
    r.h.cl = col1;
    r.h.dh = row2;   /* lower-right corner */
    r.h.dl = col2;
    r.h.bh = 2;      /* blank attribute    */
    r.h.al = num_rows;   /* row count          */
    r.h.ah = 6;      /* scroll up          */
    int86(VIDEO_INT, &r, &r);
}

void vid_mode(mode)    /* BIOS set video mode */
int mode;
{
    union REGS r;
    r.h.al = mode;   /* new mode   */
    r.h.ah = 0;      /* set video mode */
    int86(VIDEO_INT, &r, &r);
}

